#include "Ultrasonic.h"
#include <Wire.h>
#include <LiquidCrystal.h>
#include <LCDKeypad.h>

// An Ultrasonic Ranger for the Arduino
// Written by Michael Suzuki

Ultrasonic ultrasonic(2,3); // defines ultrasonic Trigger, Echo
LCDKeypad lcd;				// defines lcd
float distanceIn=0.0;		// distance input
float distance[4];			// Distance four locations
int loc=0;					// Current location to display
int x=0;					// Cursor x position
int y=0;					// Cursor y position
int posOff=0;				// Position offset
bool selectProcessed=false;
	
void error(char *str)
{
  Serial.print("error: ");
  Serial.println(str);
  while(1);
}

//Prototypes for utility functions
void takeMeasure();			// Take a measurement
void printLCD(float dist);	// Print a location
void keyCheck();			// Check for key press

void setup() {
 	Serial.begin(9600);
	Serial.println();
	Serial.println("Distance is: ");
	lcd.begin(16, 2);		// LCD is 16 x 2
	lcd.clear();			// Clear LCD
	lcd.setCursor(0,0);		// Set to 0,0
	lcd.print("Can take up to");
	lcd.setCursor(0,1);
	lcd.print("four measures");
	delay(2000);
}

void loop(){
	takeMeasure();
	lcd.clear();	
	x=0;
	y=0;
	
	// Display up to four location measurements
	switch (loc) {
		case 0:
			printLCD(distanceIn);
		break;
		case 1:
			printLCD(distance[0]);
			x=8;
			printLCD(distanceIn);
		break;
		case 2: 
			printLCD(distance[0]);
			x=8;
			printLCD(distance[1]);
			x=0;
			y=1;
			printLCD(distanceIn);
		break;
		case 3:
			printLCD(distance[0]);
			x=8;
			printLCD(distance[1]);
			x=0;
			y=1;
			printLCD(distance[2]);
			x=8;
			printLCD(distanceIn);
		break;
		case 4:
			printLCD(distance[0]);
			x=8;
			printLCD(distance[1]);
			x=0;
			y=1;
			printLCD(distance[2]);
			x=8;
			printLCD(distance[3]);
		break;
	}
	
	selectProcessed=false;
	// Look for one Select key pressed
	if (!selectProcessed){
		for (int i=0; i <= 4; i++){
            delay(500);
			keyCheck();
		} 
	}
}

//////////////////////////////////////////////////////////////////////////////////
// take Measure
//////////////////////////////////////////////////////////////////////////////////
void takeMeasure(){
	Serial.print("$, ");
	distanceIn=ultrasonic.Timing()*0.00669;
	Serial.print(distanceIn,1);
	Serial.print(" inches");
	Serial.println();
}

//////////////////////////////////////////////////////////////////////////////////
// print to LCD one location
//////////////////////////////////////////////////////////////////////////////////
void printLCD(float dist){
	bool inch=true;
	if(dist>=60.0){	// Check if Feet or Inches
		dist/=12.0;
		inch=false;
	}
	// Get position offset
	if(dist<10.0){
		x+=1;
	}
	lcd.setCursor(x,y);
	if (inch){
		lcd.print(dist,1);
		lcd.print(" In");
	}
	else{
		lcd.print(dist,2);
		lcd.print(" Ft");
	}
}
//////////////////////////////////////////////////////////////////////////////////
// Check if select key pressed
//////////////////////////////////////////////////////////////////////////////////
void keyCheck(){
	if(lcd.button()==KEYPAD_SELECT){
		distance[loc]=distanceIn;
		loc+=1;
		if(loc>4){		// This will allow setting location 4
			loc=0;
		}
		selectProcessed=true;
	}
}



